@@ -35,7 +35,7 @@ renv_bootstrap_repos <- function() {
   repos[repos == "@CRAN@"] <- "https://cloud.r-project.org"
 
   # add in renv.bootstrap.repos if set
-  default <- c(CRAN = "https://cloud.r-project.org")
+  default <- c(FALLBACK = "https://cloud.r-project.org")
   extra <- getOption("renv.bootstrap.repos", default = default)
   repos <- c(repos, extra)
 
@@ -98,24 +98,46 @@ renv_bootstrap_download_cran_latest <- function(version) {
 
   repos <- renv_bootstrap_download_cran_latest_find(version)
 
-  message("* Downloading renv ", version, " from CRAN ... ", appendLF = FALSE)
+  message("* Downloading renv ", version, " ... ", appendLF = FALSE)
 
-  info <- tryCatch(
-    utils::download.packages(
-      pkgs = "renv",
-      repos = repos,
-      destdir = tempdir(),
-      quiet = TRUE
-    ),
-    condition = identity
-  )
+  downloader <- function(type) {
 
+    tryCatch(
+      utils::download.packages(
+        pkgs = "renv",
+        destdir = tempdir(),
+        repos = repos,
+        type = type,
+        quiet = TRUE
+      ),
+      condition = identity
+    )
+
+  }
+
+  # first, try downloading a binary on Windows + macOS if appropriate
+  binary <-
+    !identical(.Platform$pkgType, "source") &&
+    !identical(getOption("pkgType"), "source") &&
+    Sys.info()[["sysname"]] %in% c("Darwin", "Windows")
+
+  if (binary) {
+    info <- downloader(type = "binary")
+    if (!inherits(info, "condition")) {
+      message("OK (downloaded binary)")
+      return(info[1, 2])
+    }
+  }
+
+  # otherwise, try downloading a source tarball
+  info <- downloader(type = "source")
   if (inherits(info, "condition")) {
     message("FAILED")
     return(FALSE)
   }
 
-  message("OK")
+  # report success and return
+  message("OK (downloaded source)")
   info[1, 2]
 
 }
@@ -157,7 +179,7 @@ renv_bootstrap_download_cran_archive <- function(version) {
   urls <- file.path(repos, "src/contrib/Archive/renv", name)
   destfile <- file.path(tempdir(), name)
 
-  message("* Downloading renv ", version, " from CRAN archive ... ", appendLF = FALSE)
+  message("* Downloading renv ", version, " ... ", appendLF = FALSE)
 
   for (url in urls) {
 
@@ -248,7 +270,7 @@ renv_bootstrap_install <- function(version, tarball, library) {
 
 }
 
-renv_bootstrap_prefix <- function() {
+renv_bootstrap_platform_prefix <- function() {
 
   # construct version prefix
   version <- paste(R.version$major, R.version$minor, sep = ".")
@@ -267,8 +289,8 @@ renv_bootstrap_prefix <- function() {
   components <- c(prefix, R.version$platform)
 
   # include prefix if provided by user
-  prefix <- Sys.getenv("RENV_PATHS_PREFIX")
-  if (nzchar(prefix))
+  prefix <- renv_bootstrap_platform_prefix_impl()
+  if (!is.na(prefix) && nzchar(prefix))
     components <- c(prefix, components)
 
   # build prefix
@@ -276,6 +298,139 @@ renv_bootstrap_prefix <- function() {
 
 }
 
+renv_bootstrap_platform_prefix_impl <- function() {
+
+  # if an explicit prefix has been supplied, use it
+  prefix <- Sys.getenv("RENV_PATHS_PREFIX", unset = NA)
+  if (!is.na(prefix))
+    return(prefix)
+
+  # if the user has requested an automatic prefix, generate it
+  auto <- Sys.getenv("RENV_PATHS_PREFIX_AUTO", unset = NA)
+  if (auto %in% c("TRUE", "True", "true", "1"))
+    return(renv_bootstrap_platform_prefix_auto())
+
+  # empty string on failure
+  ""
+
+}
+
+renv_bootstrap_platform_prefix_auto <- function() {
+
+  prefix <- tryCatch(renv_bootstrap_platform_os(), error = identity)
+  if (inherits(prefix, "error") || prefix %in% "unknown") {
+
+    msg <- paste(
+      "failed to infer current operating system",
+      "please file a bug report at https://github.com/rstudio/renv/issues",
+      sep = "; "
+    )
+
+    warning(msg)
+
+  }
+
+  prefix
+
+}
+
+renv_bootstrap_platform_os <- function() {
+
+  sysinfo <- Sys.info()
+  sysname <- sysinfo[["sysname"]]
+
+  # handle Windows + macOS up front
+  if (sysname == "Windows")
+    return("windows")
+  else if (sysname == "Darwin")
+    return("macos")
+
+  # check for os-release files
+  for (file in c("/etc/os-release", "/usr/lib/os-release"))
+    if (file.exists(file))
+      return(renv_bootstrap_platform_os_via_os_release(file, sysinfo))
+
+  # check for redhat-release files
+  if (file.exists("/etc/redhat-release"))
+    return(renv_bootstrap_platform_os_via_redhat_release())
+
+  "unknown"
+
+}
+
+renv_bootstrap_platform_os_via_os_release <- function(file, sysinfo) {
+
+  # read /etc/os-release
+  release <- utils::read.table(
+    file             = file,
+    sep              = "=",
+    quote            = c("\"", "'"),
+    col.names        = c("Key", "Value"),
+    comment.char     = "#",
+    stringsAsFactors = FALSE
+  )
+
+  vars <- as.list(release$Value)
+  names(vars) <- release$Key
+
+  # get os name
+  os <- tolower(sysinfo[["sysname"]])
+
+  # read id
+  id <- "unknown"
+  for (field in c("ID", "ID_LIKE")) {
+    if (field %in% names(vars) && nzchar(vars[[field]])) {
+      id <- vars[[field]]
+      break
+    }
+  }
+
+  # read version
+  version <- "unknown"
+  for (field in c("UBUNTU_CODENAME", "VERSION_CODENAME", "VERSION_ID", "BUILD_ID")) {
+    if (field %in% names(vars) && nzchar(vars[[field]])) {
+      version <- vars[[field]]
+      break
+    }
+  }
+
+  # join together
+  paste(c(os, id, version), collapse = "-")
+
+}
+
+renv_bootstrap_platform_os_via_redhat_release <- function() {
+
+  # read /etc/redhat-release
+  contents <- readLines("/etc/redhat-release", warn = FALSE)
+
+  # infer id
+  id <- if (grepl("centos", contents, ignore.case = TRUE))
+    "centos"
+  else if (grepl("redhat", contents, ignore.case = TRUE))
+    "redhat"
+  else
+    "unknown"
+
+  # try to find a version component (very hacky)
+  version <- "unknown"
+
+  parts <- strsplit(contents, "[[:space:]]")[[1L]]
+  for (part in parts) {
+
+    nv <- tryCatch(numeric_version(part), error = identity)
+    if (inherits(nv, "error"))
+      next
+
+    version <- nv[1, 1]
+    break
+
+  }
+
+  paste(c("linux", id, version), collapse = "-")
+
+}
+
 renv_bootstrap_library_root_name <- function(project) {
 
   # use project name as-is if requested
@@ -301,7 +456,8 @@ renv_bootstrap_library_root <- function(project) {
     return(file.path(path, name))
   }
 
-  file.path(project, "renv/library")
+  prefix <- renv_bootstrap_profile_prefix()
+  paste(c(project, prefix, "renv/library"), collapse = "/")
 
 }
 
@@ -358,3 +514,57 @@ renv_bootstrap_load <- function(project, libpath, version) {
   TRUE
 
 }
+
+renv_bootstrap_profile_load <- function(project) {
+
+  # if RENV_PROFILE is already set, just use that
+  profile <- Sys.getenv("RENV_PROFILE", unset = NA)
+  if (!is.na(profile) && nzchar(profile))
+    return(profile)
+
+  # check for a profile file (nothing to do if it doesn't exist)
+  path <- file.path(project, "renv/local/profile")
+  if (!file.exists(path))
+    return(NULL)
+
+  # read the profile, and set it if it exists
+  contents <- readLines(path, warn = FALSE)
+  if (length(contents) == 0L)
+    return(NULL)
+
+  # set RENV_PROFILE
+  profile <- contents[[1L]]
+  if (nzchar(profile))
+    Sys.setenv(RENV_PROFILE = profile)
+
+  profile
+
+}
+
+renv_bootstrap_profile_prefix <- function() {
+  profile <- renv_bootstrap_profile_get()
+  if (!is.null(profile))
+    return(file.path("renv/profiles", profile))
+}
+
+renv_bootstrap_profile_get <- function() {
+  profile <- Sys.getenv("RENV_PROFILE", unset = "")
+  renv_bootstrap_profile_normalize(profile)
+}
+
+renv_bootstrap_profile_set <- function(profile) {
+  profile <- renv_bootstrap_profile_normalize(profile)
+  if (is.null(profile))
+    Sys.unsetenv("RENV_PROFILE")
+  else
+    Sys.setenv(RENV_PROFILE = profile)
+}
+
+renv_bootstrap_profile_normalize <- function(profile) {
+
+  if (is.null(profile) || profile %in% c("", "default"))
+    return(NULL)
+
+  profile
+
+}
