@@ -770,7 +770,7 @@ renv_retrieve_handle_remotes <- function(record) {
     # TODO: allow customization of behavior when remote parsing fails?
     remote <- catch(renv_remotes_resolve(field))
     if (inherits(remote, "error")) {
-      fmt <- "failed to parse remote '%s' declared by package '%s'; skipping"
+      fmt <- "failed to resolve remote '%s' declared by package '%s'; skipping"
       warningf(fmt, field, record$Package)
       next
     }
@@ -780,14 +780,19 @@ renv_retrieve_handle_remotes <- function(record) {
     # the user (ie: it's been requested as it's a dependency of this package)
     # then update the record. note that we don't want to update in explicit
     # installs as we don't want to override what was reported / requested
-    # in e.g. `renv::restore()`
+    # in e.g. `renv::restore()`.
+    #
+    # allow override if a non-specific version of the package was requested
+    package <- remote$Package
     state <- renv_restore_state()
-    if (remote$Package %in% state$packages)
-      next
+    if (package %in% state$packages) {
+      record <- state$records[[package]]
+      if (!identical(record, list(Package = package, Source = "Repository")))
+        next
+    }
 
-    records <- state$records
-    records[[remote$Package]] <- remote
-    state$records <- records
+    # update the record
+    state$records[[package]] <- remote
 
   }
 
